<template>
  <div class="dialog-table-container sub-page-inner">
    <div class="sub-table-container">
      <el-table :element-loading-background="loadingColor" v-loading="loading" height="calc(100% - 120px)"
        highlight-current-row current-row-key="id" align="center" :data="tableData" class="dialog_table"
        :cell-style="{ 'text-align': 'center' }" :header-cell-style="{ 'text-align': 'center' }" ref="myTable"
        @current-change="currentChange">
        <el-table-column type="index" label="序号" width="60">
        </el-table-column>

        <el-table-column prop="completedWork" :label="listType === 6
          ? '平台名称'
          : listType === 5
            ? '制度名称'
            : '应用名称'
          ">
        </el-table-column>
        <!-- <el-table-column prop="projectName" label="项目名称"> </el-table-column> -->
        <el-table-column prop="createTime" label="搭建日期" width="110">
        </el-table-column>
      </el-table>
      <pagenation :pageResult="params.pageBean" @currentChange="pageChange" class="pagenation"></pagenation>
    </div>
    <div class="sub-page-detail">
      <div class="bg-de">
        <div class="de-con">
          <div>
            <img v-for="(item, index) in 2" :key="index" src="@/assets/img/bigScreen/img_wk_zs2@2x.png" />
          </div>
          <div class="title">{{ currentRow.projectName }}</div>
          <div>
            <img v-for="(item, index) in 2" :key="index" src="@/assets/img/bigScreen/img_wk_zs2@2x.png" />
          </div>
        </div>
      </div>
      <el-form label-position="top" class="sub-page--expand" :element-loading-background="loadingColor"
        v-loading="loading">
        <el-row>
          <el-form-item label="解决问题：">
            <span>{{ infoData.problems }}</span>
          </el-form-item>
        </el-row>
        <el-row>
          <el-form-item label="运行实效：">
            <span>{{ infoData.workPlan }}</span>
          </el-form-item>
        </el-row>
        <el-row>
          <el-form-item label="佐证材料：">
            <el-row>
              <FileList :fileList="infoData.defaultFileList" :isDelete="false" :classified="infoData.classified &&
                (!infoData.defaultFileList ||
                  !infoData.defaultFileList.length)
                "></FileList>
            </el-row>
          </el-form-item>
        </el-row>
      </el-form>
    </div>
  </div>
</template>

<script>
import FileList from '@/components/uploadFile/FileList.vue'
import pagenation from './pagenation.vue'
import apiList from '@/api/bigScreen/majorView.js'
import moment from 'moment'
const portal = window.context.portal
export default {
  name: 'importantPlatform',
  components: { pagenation, FileList },
  props: {
    options: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      currentRow: {},
      reqLoading: false,
      previewUrl: `${portal}/file/onlinePreviewController/v1/getFileById_`,
      loading: false,
      loadingColor: 'rgba(6, 46, 106, 0.4)',
      tableData: [],
      params: {
        pageBean: {
          page: 1,
          pageSize: 10,
          total: 0,
          showTotal: true
        },
        params: {},
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'r.RESULT_FORM_',
            relation: 'AND',
            value: 2
          }
        ]
      },
      paramsFile: {
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'BIZ_ID_',
            relation: 'AND',
            value: ''
          }
        ]
      },
      pageBean: {
        page: 1,
        pageSize: 20,
        showTotal: true
      },
      infoData: {},
      isShow: 1,
      listType: 0
    }
  },
  mounted() {
    this.listType = this.$route.query.type
    this.$bus.$on('changeDate', searchDate => {
      this.getResultList()
    })
    this.getResultList()
    this.$emit('searchDateChange')
  },
  methods: {
    currentChange(currentRow, oldCurrentRow) {
      this.currentRow = currentRow
      this.handleDetail(currentRow)
    },
    getResultList() {
      this.loading = true
      let searchDate = JSON.parse(sessionStorage.getItem('searchDate'))
      let { type, projectId } = this.$route.query
      let type1 = type == 5 ? [4, 5] : []
      let data1 = {
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 's.PLAN_YEAR_', // 字段名
            relation: 'AND',
            value: searchDate.year
          },
          {
            group: 'main',
            operation: 'LESS_EQUAL',
            parentGroup: '',
            property: 's.PLAN_MONTH_', // 字段名
            relation: 'AND',
            value: searchDate.month
          },
          {
            group: 'main',
            operation: 'IN',
            parentGroup: '',
            property: 's.PLAN_type_',
            relation: 'AND',
            value: type1
          },
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'm.id_',
            relation: 'AND',
            value: projectId
          }
        ]
      }
      data1.pageBean = this.pageBean
      apiList.getResultList(data1, res => {
        if (res && res.rows) {
          this.params.pageBean.page = res.page
          this.params.pageBean.pageSize = res.pageSize
          this.params.pageBean.total = res.total
          this.tableData = res.rows.map(item => {
            item.createTime = moment(item.createTime).format('YYYY-MM-DD')
            return item
          })
          if (this.tableData.length) {
            this.currentRow = this.tableData[0]
            this.$nextTick(() => {
              this.$refs.myTable.setCurrentRow(this.$refs.myTable.data[0])
            })
          } else {
            this.currentRow = {}
            this.infoData = {}
          }
        }
        this.loading = false
      })
    },
    handleDetail(row) {
      apiList.getResultD(row.id, res => {
        if (res) {
          this.infoData = res
        }
      })
    },
    pageChange() {
      this.getResultList(this.listType)
    },
    expandChange(row, expandedRows) {
      console.log(row, expandedRows)
      if (row.fileList) return
      this.getFiles(row)
    },
    getFiles(row) {
      this.paramsFile.querys[0].value = row.id
      apiList.getFiles(this.paramsFile, data => {
        row.fileList = data.rows
      })
      let index = this.tableData.findIndex(item => item.id == row.id)
      this.tableData.splice(index, 1, row)
    },
    handlePreview(file) {
      let id = file.fileId
        ? file.fileId
        : file.id
          ? file.id
          : file.response.fileId
      let type = file.fileType || (file.extensionName
        ? file.extensionName
        : file.name.split('.')[1])
      this.$refs.filePreview.previewUrl = this.previewUrl + id
      this.$refs.filePreview.open(type)
    },
    // 文件下载
    handleDownloadFile(file) {
      console.log(file)
      let id = file.fileId
        ? file.fileId
        : file.id
          ? file.id
          : file.response.fileId
      window.open(portal + `/file/v1/downloadFile?fileId=${id}`, '_self')
    },
    loadData() {
      this.loading = true
      let searchDate = sessionStorage.getItem('searchDate')
      searchDate = JSON.parse(searchDate)
      this.params.params = {
        year: searchDate.year,
        quarter: searchDate.quarter
      }
      // this.params.querys[1].value = searchDate.year
      // this.params.querys[2].value = searchDate.quarter
      apiList.getPilotResultDetail(this.params, res => {
        if (res && res.rows) {
          this.tableData = res.rows
          this.params.pageBean.page = res.page
          this.params.pageBean.pageSize = res.pageSize
          this.params.pageBean.total = res.total
        }
        this.loading = false
      })
    }
  }
}
</script>
<style lang="scss" scoped>
/deep/.file-item {
  border: none !important;

  .file_name {
    font-size: 14PX !important;
    max-width: 60%;
  }
}

/deep/.classified {
  font-size: 14PX !important;
}

.myInfo {
  /deep/.el-descriptions__body {
    // background: transparent;
    background: rgba(2, 62, 141, 1);
    box-sizing: border-box;

    .el-descriptions__table {
      // background: transparent;
      background: rgba(2, 62, 141, 1);

      th,
      tr,
      td {
        background: rgba(2, 62, 141, 1);
        color: #f3f3f3;
      }
    }
  }

  /deep/.el-descriptions .is-bordered .el-descriptions-item__cell {
    // border: 1px #01215a solid;
    // border-left: none;
    border: none;
  }
}

/deep/.el-table__expand-column .cell {
  width: 0;
  height: 0;
  display: none;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
